==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/components/camel-aws/camel-aws2-ecs/src/main/java/org/apache/camel/component/aws2/ecs/client/ECS2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.ecs.client;

import org.apache.camel.component.aws2.ecs.ECS2Configuration;
import org.apache.camel.component.aws2.ecs.client.impl.ECS2ClientIAMOptimizedImpl;
import org.apache.camel.component.aws2.ecs.client.impl.ECS2ClientIAMProfileOptimizedImpl;
import org.apache.camel.component.aws2.ecs.client.impl.ECS2ClientSessionTokenImpl;
import org.apache.camel.component.aws2.ecs.client.impl.ECS2ClientStandardImpl;

/**
 * Factory class to return the correct type of AWS Athena client.
 */
public final class ECS2ClientFactory {

    private ECS2ClientFactory() {
    }

    /**
     * Return the correct AWS ECS client (based on remote vs local).
     *
     * @param  configuration configuration
     * @return               EcsClient
     */
    public static ECS2InternalClient getEcsClient(ECS2Configuration configuration) {
        if (Boolean.TRUE.equals(configuration.isUseDefaultCredentialsProvider())) {
            return new ECS2ClientIAMOptimizedImpl(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseProfileCredentialsProvider())) {
            return new ECS2ClientIAMProfileOptimizedImpl(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseSessionCredentials())) {
            return new ECS2ClientSessionTokenImpl(configuration);
        } else {
            return new ECS2ClientStandardImpl(configuration);
        }
    }
}

==> apache-camel-4.18.0-src.zip: apache-camel-4.18.0/components/camel-aws/camel-aws2-ecs/src/main/java/org/apache/camel/component/aws2/ecs/client/ECS2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.ecs.client;

import org.apache.camel.component.aws.common.AwsClientBuilderUtil;
import org.apache.camel.component.aws2.ecs.ECS2Configuration;
import software.amazon.awssdk.services.ecs.EcsClient;

/**
 * Factory class to create AWS ECS clients using common configuration.
 */
public final class ECS2ClientFactory {

    private ECS2ClientFactory() {
    }

    /**
     * Create an ECS client based on configuration.
     *
     * @param  configuration The ECS configuration
     * @return               Configured EcsClient
     */
    public static EcsClient getEcsClient(ECS2Configuration configuration) {
        return AwsClientBuilderUtil.buildClient(
                configuration,
                EcsClient::builder);
    }
}
